%define realversion 2020-07-29
%define version %(echo %{realversion} | sed -e 's/-//g')
%define releasenum 1

%if 0%{?fedora} >= 11 || 0%{?rhel} >= 5
%global useselinux 1
%else 
%global useselinux 0
%endif

Name:        dokuwiki
Version:     %{version}
Release:     %{releasenum}%{?dist}
Summary:     Standards compliant simple to use wiki
Group:       Applications/Internet
License:     GPLv2
URL:         http://www.dokuwiki.org/dokuwiki
Source:      http://download.dokuwiki.org/src/dokuwiki/%{name}-%{realversion}.tgz

BuildRoot:   %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildArch:   noarch
Requires:    php
Requires:    rh-php73-php-gd
Requires:    rh-php73-php-imap
Requires:    rh-php73-php-ldap
Requires:    httpd

%description
DokuWiki is a standards compliant, simple to use Wiki, mainly aimed at creating 
documentation of any kind. It has a simple but powerful syntax which makes sure 
the data files remain readable outside the Wiki and eases the creation of 
structured texts. 

All data is stored in plain text files no database is required. 


%prep
%setup -q -n %{name}-%{realversion}

chmod a-x inc/lang/az/*.{txt,html}

mv -f conf/mysql.conf.php.example .

sed -i "s:'./data':'%{_localstatedir}/lib/%{name}/data':" conf/%{name}.php
sed -i "s:ALL        8:ALL        1:" conf/acl.auth.php.dist

# Use admin as default superuser
echo "\$conf['superuser'] = 'admin';" >> conf/local.php.dist

cat <<EOF >%{name}.httpd
# %{name}
# %{summary}
# %{version}
#

Alias /%{name} %{_datadir}/%{name}

<Directory %{_datadir}/%{name}>
    Options +FollowSymLinks
    <IfModule !mod_authz_core.c>
      Order Allow,Deny
      Allow from 127.0.0.1 ::1
    </IfModule>
    <IfModule mod_authz_core.c>
      Require ip 127.0.0.1 ::1
    </IfModule>
</Directory>

<Directory %{_datadir}/%{name}/inc>
    <IfModule !mod_authz_core.c>
      Order Deny,Allow
      Deny from all
    </IfModule>
    <IfModule mod_authz_core.c>
      Require all denied
    </IfModule>
</Directory>

<Directory %{_datadir}/%{name}/inc/lang>
    <IfModule !mod_authz_core.c>
      Order Deny,Allow
      Deny from all
    </IfModule>
    <IfModule mod_authz_core.c>
      Require all denied
    </IfModule>
</Directory>

<Directory %{_datadir}/%{name}/lib/_fla>
    <IfModule !mod_authz_core.c>
      Order allow,deny
      Deny from all
    </IfModule>
    <IfModule mod_authz_core.c>
      Require all denied
    </IfModule>
</Directory>

<Directory %{_sysconfdir}/%{name}>
    <IfModule !mod_authz_core.c>
      Order Deny,Allow
      Deny from all
    </IfModule>
    <IfModule mod_authz_core.c>
      Require all denied
    </IfModule>
</Directory>
<Directory %{_datadir}/%{name}/conf>
    <IfModule !mod_authz_core.c>
      Order allow,deny
      Deny from all
    </IfModule>
    <IfModule mod_authz_core.c>
      Require all denied
    </IfModule>
</Directory>

<Directory %{_localstatedir}/lib/%{name}/>
    <IfModule !mod_authz_core.c>
      Order Deny,Allow
      Deny from all
    </IfModule>
    <IfModule mod_authz_core.c>
      Require all denied
    </IfModule>
</Directory>
<Directory %{_datadir}/%{name}/data>
    <IfModule !mod_authz_core.c>
      Order allow,deny
      Deny from all
    </IfModule>
    <IfModule mod_authz_core.c>
      Require all denied
    </IfModule>
</Directory>

EOF

cat <<EOF >DOKUWIKI-SELINUX.README
%{name}-selinux
====================

This package configures dokuwiki to run in
SELinux enabled environments

EOF

%build
# nothing to do here

%install
rm -rf $RPM_BUILD_ROOT
install -d -p $RPM_BUILD_ROOT%{_sysconfdir}/%{name}
install -d -p $RPM_BUILD_ROOT%{_sysconfdir}/httpd/conf.d
install -d -p $RPM_BUILD_ROOT%{_datadir}/%{name}
install -d -p $RPM_BUILD_ROOT%{_datadir}/%{name}/bin
install -d -p $RPM_BUILD_ROOT%{_localstatedir}/lib/%{name}
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/lib/%{name}/data/{index,tmp,media,attic,pages,cache,meta,locks,media_attic,media_meta}
rm -f install.php
rm -f inc/.htaccess
rm -f inc/lang/.htaccess
rm -f lib/_fla/{.htaccess,README}
rm -f lib/plugins/revert/lang/sk/intro.txt
cp -rp data/pages/* $RPM_BUILD_ROOT%{_localstatedir}/lib/%{name}/data/pages/
cp -rp conf/* $RPM_BUILD_ROOT%{_sysconfdir}/%{name}
cp -rp bin/*  $RPM_BUILD_ROOT%{_datadir}/%{name}/bin
cp -rp lib  $RPM_BUILD_ROOT%{_datadir}/%{name}/
cp -rp inc  $RPM_BUILD_ROOT%{_datadir}/%{name}/
cp -rp vendor $RPM_BUILD_ROOT%{_datadir}/%{name}/
install -p -m0644 VERSION $RPM_BUILD_ROOT%{_datadir}/%{name}
install -p -m0644 *.php $RPM_BUILD_ROOT%{_datadir}/%{name}
install -p -m0644 %{name}.httpd $RPM_BUILD_ROOT%{_sysconfdir}/httpd/conf.d/%{name}.conf

pushd $RPM_BUILD_ROOT%{_sysconfdir}/%{name}
for d in *.dist; do
    d0=`basename $d .dist`
    if [ ! -f "$d0" ]; then
        mv -f $d $d0
    fi
done
popd

pushd $RPM_BUILD_ROOT%{_datadir}/%{name}
    ln -sf ../../../etc/%name conf
    ln -sf ../../../%{_localstatedir}/lib/%{name}/data/ data
popd

%clean
rm -rf $RPM_BUILD_ROOT

%post
%if %{useselinux}
(
semanage fcontext -a -t httpd_sys_content_t '%{_sysconfdir}/%{name}(/.*)?'
semanage fcontext -a -t httpd_sys_content_t '%{_datadir}/%{name}(/.*)?'
semanage fcontext -a -t httpd_sys_content_t '%{_datadir}/%{name}/lib/plugins(/.*)?'
restorecon -R '%{_sysconfdir}/%{name}'
restorecon -R '%{_datadir}/%{name}'
restorecon -R '%{_datadir}/%{name}/lib/plugins'
) &> /dev/null || :
%endif


%postun
%if %{useselinux}
(
if [ $1 -eq 0 ] ; then
semanage fcontext -d -t httpd_sys_content_t '%{_sysconfdir}/%{name}(/.*)?'
semanage fcontext -d -t httpd_sys_content_t '%{_datadir}/%{name}(/.*)?'
semanage fcontext -d -t httpd_sys_content_t '%{_datadir}/%{name}/lib/plugins(/.*)?'
fi
) &> /dev/null || :
%endif

%files
%defattr(-,root,root,-)
%doc COPYING README mysql.conf.php.example DOKUWIKI-SELINUX.README
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{name}.conf
%config(noreplace) %attr(0644,apache,apache) %{_sysconfdir}/%{name}/*
%dir %attr(0755,apache,apache) %{_sysconfdir}/%{name}
%attr(0755,apache,apache) %{_datadir}/%{name}/bin/*.php
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/conf
%{_datadir}/%{name}/data
%{_datadir}/%{name}/*.php
%{_datadir}/%{name}/VERSION
%dir %{_datadir}/%{name}/lib
%{_datadir}/%{name}/lib/exe
%{_datadir}/%{name}/lib/images
%{_datadir}/%{name}/lib/index.html
%{_datadir}/%{name}/lib/scripts
%{_datadir}/%{name}/lib/styles
%{_datadir}/%{name}/lib/tpl
#%{_datadir}/%{name}/lib/_fla
%attr(0755,apache,apache) %dir %{_datadir}/%{name}/lib/plugins
%{_datadir}/%{name}/lib/plugins/*
%{_datadir}/%{name}/inc
%{_datadir}/%{name}/vendor
%dir %{_localstatedir}/lib/%{name}
%attr(0750,apache,apache) %dir %{_localstatedir}/lib/%{name}/data
%attr(0755,apache,apache) %dir %{_localstatedir}/lib/%{name}/data/media
%attr(0755,apache,apache) %dir %{_localstatedir}/lib/%{name}/data/media_attic
%attr(0755,apache,apache) %dir %{_localstatedir}/lib/%{name}/data/media_meta
%attr(0755,apache,apache) %dir %{_localstatedir}/lib/%{name}/data/attic
%attr(0755,apache,apache) %dir %{_localstatedir}/lib/%{name}/data/cache
%attr(0755,apache,apache) %dir %{_localstatedir}/lib/%{name}/data/meta
%attr(0755,apache,apache) %dir %{_localstatedir}/lib/%{name}/data/locks
%attr(0755,apache,apache) %dir %{_localstatedir}/lib/%{name}/data/tmp
%attr(0755,apache,apache) %dir %{_localstatedir}/lib/%{name}/data/index
%attr(0755,apache,apache) %dir %{_localstatedir}/lib/%{name}/data/pages
%attr(0755,apache,apache) %dir %{_localstatedir}/lib/%{name}/data/pages/playground
%attr(0755,apache,apache) %dir %{_localstatedir}/lib/%{name}/data/pages/wiki
%attr(0644,apache,apache) %{_localstatedir}/lib/%{name}/data/pages/*/*

%changelog
* Tue Aug 04 2020 Stephane de Labrusse <stephdl@de-labrusse.fr> - 07.29.ns7.sdl
- Bump to 2020-07-29 (Stephane de Labrusse <stephdl@de-labrusse.fr>)
- require rh-php73 (Stephane de Labrusse <stephdl@de-labrusse.fr>)
- bump to 2018-04-22c "Greebo" (Stephane de Labrusse <stephdl@de-labrusse.fr>)
- * Sat Mar 16 2019 Stephane de Labrusse <stephdl@de-labrusse.fr> 2018-04-22b-1 - Update to 2018-04-22b Greebo (Stephane de Labrusse <stephdl@de-labrusse.fr>)
- upgrade to 2018-04-22b (Stephane de Labrusse <stephdl@de-labrusse.fr>)
- * Sat May 05 2018 Stephane de Labrusse <stephdl@de-labrusse.fr> 2018-04-22a-1 - Update to 2018-04-22a Greebo (Stephane de Labrusse <stephdl@de-labrusse.fr>)
- * Tue May 01 2018 Stephane de Labrusse <stephdl@de-labrusse.fr> 2018-04-22-1 - Update to 2018-04-22 Greebo - rh-php71-fpm is default (Stephane de Labrusse <stephdl@de-labrusse.fr>)
